<?php
/**
 * Core
 *
 * WEB3 MoWeb3Loader.
 *
 * @category   Common, Core, UI
 * @package    MoWeb3
 * @author     miniOrange <info@xecurify.com>
 * @license    http://www.gnu.org/copyleft/gpl.html GNU/GPL, see LICENSE.php
 * @link       https://miniorange.com
 */

namespace MoWeb3\Base;

use MoWeb3\Base\MoWeb3InstanceHelper;
use MoWeb3\MoWeb3Utils;
use MoWeb3\view\SetupGuideView\MoWeb3GuideView;
use MoWeb3\view\ContentRestrictionView\MoWeb3ContentRestriction;
use MoWeb3\view\PremiumPlan\MoWeb3PremiumPlan;
use MoWeb3\view\ShortcodeInfoView\MoWeb3ShortcodeInfo;
use MoWeb3\view\RoleMappingView\MoWeb3RoleMapping;




/**
 * Class to save Load and Render REST API UI
 *
 * @category Common, Core
 * @package  MoWeb3\Standard
 * @author   miniOrange <info@xecurify.com>
 * @license  http://www.gnu.org/copyleft/gpl.html GNU/GPL, see LICENSE.php
 * @link     https://miniorange.com
 */

class MoWeb3Loader {

	/**
	 * Instance Helper
	 *
	 * @var \MoWeb3\Base\MoWeb3InstanceHelper $instance_helper
	 **/
	private $instance_helper;
	private $moweb3_util;
	private $moweb3_guide;
	private $moweb3_content_restriction;
	private $moweb3_premium_plan;

	/**
	 * Constructor
	 */
	public function __construct() {
		add_action( 'admin_enqueue_scripts', array( $this, 'plugin_settings_style' ) );
		add_action( 'admin_enqueue_scripts', array( $this, 'plugin_settings_script' ) );
		$this->moweb3_util     = new MoWeb3Utils();
		$this->instance_helper = new MoWeb3InstanceHelper();
	}

	/**
	 * Function to enqueue CSS
	 */
	public function plugin_settings_style() {
		wp_enqueue_style( 'mo_web3_admin_settings_style', MOWEB3_URL . 'resources/css/style_settings.css', array(), $ver = "1.0.1", $in_footer = false );
		wp_enqueue_style( 'mo_web3_admin_settings_phone_style', MOWEB3_URL . 'resources/css/phone.css', array(), $ver    = "1.0.1", $in_footer = false );
	}

	/**
	 * Function to enqueue JS
	 */

	public function plugin_settings_script() {
		
		wp_enqueue_script( 'mo_web3_admin_settings_script', MOWEB3_URL . 'resources/js/settings.js', array(), $ver = "1.0.1", $in_footer = false );
		wp_enqueue_script( 'mo_web3_admin_settings_phone_script', MOWEB3_URL . 'resources/js/phone.js', array(), $ver = "1.0.1", $in_footer = false );
	}

	/**
	 * Function to load appropriate view
	 *
	 * @param string $currenttab Tab to load and render view for.
	 *
	 * @return void
	 */

	
	public function load_current_tab( $currenttab ) {
		global $mo_web3_util;
		$accounts = $this->instance_helper->get_accounts_instance();
		if( 'account' === $currenttab) {

			if ( $mo_web3_util->mo_web3_get_option( 'mo_web3_verify_customer' ) === 'true' ) {
				$accounts->verify_password_ui();
			} elseif ( trim( $mo_web3_util->mo_web3_get_option( 'mo_web3_admin_email' ) ) !== '' && trim( $mo_web3_util->mo_web3_get_option( 'mo_web3_admin_api_key' ) ) === '' && $mo_web3_util->mo_web3_get_option( 'mo_web3_new_registration' ) !== 'true' ) {
				$accounts->verify_password_ui();
			} else {
				$accounts->register();
			}
			
		}
        elseif( 'config' === $currenttab || '' === $currenttab ) {
		 	$this->instance_helper->get_config_instance()->render_ui();
		}
		elseif("setup_guide"=== $currenttab){
			$this->moweb3_guide   = new MoWeb3GuideView();
			$this->moweb3_guide->view();
		}
		elseif("content_restriction"=== $currenttab){
			$this->moweb3_content_restriction = new MoWeb3ContentRestriction();
			$this->moweb3_content_restriction->view();
		}
		elseif("shortcode_info"=== $currenttab){
			$this->moweb3_shortcode_info = new MoWeb3ShortcodeInfo();
			$this->moweb3_shortcode_info->view();
		}		
		elseif("role_mapping"=== $currenttab){
			$this->moweb3_role_mapping = new MoWeb3RoleMapping();
			$this->moweb3_role_mapping->view();
		}
		elseif("licensing"=== $currenttab){
			$this->moweb3_premium_plan = new MoWeb3PremiumPlan();
			$this->moweb3_premium_plan->view();
		}
	}
	
}
?>